mask64x8

Struct mask64x8 

#[repr(C, align(64))]
pub struct mask64x8<S: Simd> { pub(crate) val: S::mask64x8, pub simd: S, }
A SIMD mask of 8 64-bit elements.

When created from a comparison operation, and as it should be used in a Self::select operation, each element will be all ones if it’s “true”, and all zeroes if it’s “false”.

Fields

val: S::mask64x8simd: S